@@ -1,8 +1,10 @@
 import logging
 import threading
+from typing import TYPE_CHECKING
 
 from pyvex.errors import LiftingException
 from pyvex.native import ffi, pvc
+from pyvex.types import CLiftSource, LibvexArch
 
 from .lift_function import Lifter
 
@@ -23,6 +25,7 @@ LIBVEX_SUPPORTED_ARCHES = {
     "PPC32",
     "PPC64",
     "S390X",
+    "RISCV64",
 }
 
 VEX_MAX_INSTRUCTIONS = 99
@@ -47,12 +50,16 @@ class LibVEXLifter(Lifter):
     def get_vex_log():
         return bytes(ffi.buffer(pvc.msg_buffer, pvc.msg_current_size)).decode() if pvc.msg_buffer != ffi.NULL else None
 
-    def lift(self):
+    def _lift(self):
+        if TYPE_CHECKING:
+            assert isinstance(self.irsb.arch, LibvexArch)
+            assert isinstance(self.data, CLiftSource)
         try:
             _libvex_lock.acquire()
 
             pvc.log_level = log.getEffectiveLevel()
-            vex_arch = getattr(pvc, self.irsb.arch.vex_arch)
+            vex_arch = getattr(pvc, self.irsb.arch.vex_arch, None)
+            assert vex_arch is not None
 
             if self.bytes_offset is None:
                 self.bytes_offset = 0
